@@ -9,6 +9,7 @@ ALLOW_SOURCE = 'allow_source'
 BROADCASTS = 'broadcasts'
 CHANNEL = 'channel'
 CLIENT_ID = 'client_id'
+DIRECTION = 'direction'
 ERROR = 'error'
 FEATURED = 'featured'
 FOLLOWS = 'follows'
@@ -24,6 +25,9 @@ OFFSET = 'offset'
 PERIOD = 'period'
 QUERY = 'query'
 SIG = 'sig'
+SORT_BY = 'sortby'
+TARGET = 'target'
+TEAM = 'team'
 TOKEN = 'token'
 TYPE = 'type'
 USER = 'user'
